Print method for constructed EpiStrainDynamics models
Source:R/construct_model.R
print.EpiStrainDynamics.model.RdPrints a concise summary instead of dumping the full data and standata list to the console.
Usage
# S3 method for class 'EpiStrainDynamics.model'
print(x, ...)Arguments
- x
an
EpiStrainDynamics.modelobject, as returned byconstruct_model()- ...
further arguments passed to or from other methods (unused)
Examples
mod <- construct_model(
pathogen_structure = single(
data = sarscov2,
case_timeseries = "cases",
time = "date"
),
method = random_walk()
)
print(mod)
#> <EpiStrainDynamics model>
#> Method: Random walk
#> Pathogen structure: single
#> Pathogens: cases
#> Observations: 830
#> Day-of-week effect: FALSE
#>
#> Data (head):
#> # A tsibble: 6 x 2 [1D]
#> date case_timeseries
#> <date> <dbl>
#> 1 2020-09-23 7096
#> 2 2020-09-24 7682
#> 3 2020-09-25 7318
#> 4 2020-09-26 6810
#> 5 2020-09-27 7023
#> 6 2020-09-28 9983